Crate webtrans

Crate webtrans 

WebTransport library for native and WebAssembly

  • Native (non-wasm32): Quinn-based HTTP/3 + QUIC implementation via webtrans-quinn
  • WebAssembly (wasm32): Browser WebTransport API bindings via webtrans-wasm

Re-exports

pub use webtrans_quinn as quinn;

Modules

crypto
Simple crypto provider utilities for rustls.
tls
TLS helpers for managing certificates and private keys.

Structs

Client
A client for connecting to a WebTransport server.
ClientBuilder
Construct a WebTransport Client using sensible defaults.
ConnectRequest
Decoded WebTransport CONNECT request metadata.
ConnectResponse
Decoded WebTransport CONNECT response metadata.
Frame
HTTP/3 frame type identifier.
RecvStream
A stream that can be used to receive bytes. See quinn::RecvStream.
Request
A mostly complete WebTransport handshake awaiting server accept/reject based on URL.
SendStream
A stream that can be used to send bytes. See quinn::SendStream.
Server
A WebTransport server that accepts new sessions.
ServerBuilder
Construct a WebTransport Server using sensible defaults.
Session
An established WebTransport session, acting like a full QUIC connection. See quinn::Connection.
Setting
HTTP/3 SETTINGS identifier.
Settings
Parsed HTTP/3 settings map keyed by Setting.
UniStream
Sent as the leading bytes on a unidirectional stream to indicate its stream type.
VarInt
An integer less than 2^62.
VarIntBoundsExceeded
Error returned when constructing a VarInt from a value >= 2^62.
VarIntUnexpectedEnd
Error returned when a varint decode reaches EOF before all bytes are available.

Enums

Capsule
WebTransport HTTP/3 capsule payloads.
CapsuleError
Errors returned by capsule encoding and decoding.
CongestionControl
Congestion control algorithm to use for the connection.
ConnectError
Errors returned while encoding or decoding WebTransport CONNECT messages.
Error
Error categories that can occur when using WebTransport.
SettingsError
Errors returned while encoding or decoding SETTINGS exchanges.

Functions

error_from_http3
Map an HTTP/3 application error code into WebTransport error space.
error_to_http3
Map a WebTransport application error code into the reserved HTTP/3 space.

Type Aliases

Result
Convenience result type for WebTransport protocol and transport operations.