WebTransport library for native and WebAssembly
- Native (
non-wasm32): Quinn-based HTTP/3 + QUIC implementation via webtrans-quinn - WebAssembly (
wasm32): Browser WebTransport API bindings via webtrans-wasm
Re-exports
pub use webtrans_quinn as quinn;
Modules
- crypto
- Simple crypto provider utilities for rustls.
- tls
- TLS helpers for managing certificates and private keys.
Structs
- Client
- A client for connecting to a WebTransport server.
- Client
Builder - Construct a WebTransport Client using sensible defaults.
- Connect
Request - Decoded WebTransport CONNECT request metadata.
- Connect
Response - Decoded WebTransport CONNECT response metadata.
- Frame
- HTTP/3 frame type identifier.
- Recv
Stream - A stream that can be used to receive bytes. See
quinn::RecvStream. - Request
- A mostly complete WebTransport handshake awaiting server accept/reject based on URL.
- Send
Stream - A stream that can be used to send bytes. See
quinn::SendStream. - Server
- A WebTransport server that accepts new sessions.
- Server
Builder - Construct a WebTransport Server using sensible defaults.
- Session
- An established WebTransport session, acting like a full QUIC connection. See
quinn::Connection. - Setting
- HTTP/3 SETTINGS identifier.
- Settings
- Parsed HTTP/3 settings map keyed by
Setting. - UniStream
- Sent as the leading bytes on a unidirectional stream to indicate its stream type.
- VarInt
- An integer less than 2^62.
- VarInt
Bounds Exceeded - Error returned when constructing a
VarIntfrom a value >= 2^62. - VarInt
Unexpected End - Error returned when a varint decode reaches EOF before all bytes are available.
Enums
- Capsule
- WebTransport HTTP/3 capsule payloads.
- Capsule
Error - Errors returned by capsule encoding and decoding.
- Congestion
Control - Congestion control algorithm to use for the connection.
- Connect
Error - Errors returned while encoding or decoding WebTransport CONNECT messages.
- Error
- Error categories that can occur when using WebTransport.
- Settings
Error - Errors returned while encoding or decoding SETTINGS exchanges.
Functions
- error_
from_ http3 - Map an HTTP/3 application error code into WebTransport error space.
- error_
to_ http3 - Map a WebTransport application error code into the reserved HTTP/3 space.
Type Aliases
- Result
- Convenience result type for WebTransport protocol and transport operations.